@@ -9,7 +9,7 @@ __title__ = "SIESTAstepper"
 __author__ = "Eftal Gezer"
 __license__ = "GNU GPL v3"
 __copyright__ = "Copyright 2022, Eftal Gezer"
-__version__ = "2.0.0"
+__version__ = "2.1.0"
 
 from .core import (
     run,
@@ -21,8 +21,15 @@ from .core import (
     copy_files,
     ani_to_fdf,
     xyz_to_fdf,
+    xv_to_fdf,
+    log_to_fdf,
+    xv_to_ani,
     merge_ani,
-    analysis,
+    ani_to_gif,
+    energy_analysis,
+    force_analysis,
     energy_diff,
+    force_diff,
+    pair_correlation_function,
     settings
 )
